@@ -1,12 +1,5 @@
-/* LICENSE BEGIN
-    This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
-
-    SPDX-License-Identifier: GPL-3.0-only
-    This file is also available under commercial licensing terms.
-    Please contact info@sixtyfps.io for more information.
-LICENSE END */
+// Copyright © SixtyFPS GmbH <info@sixtyfps.io>
+// SPDX-License-Identifier: (GPL-3.0-only OR LicenseRef-SixtyFPS-commercial)
 
 /*!
 
@@ -24,6 +17,8 @@ only be used with `version = "=x.y.z"` in Cargo.toml.
 #![doc(html_logo_url = "https://sixtyfps.io/resources/logo.drawio.svg")]
 
 extern crate proc_macro;
+use std::path::Path;
+
 use proc_macro::{Spacing, TokenStream, TokenTree};
 use quote::quote;
 use sixtyfps_compilerlib::diagnostics::BuildDiagnostics;
@@ -345,20 +340,48 @@ pub fn sixtyfps(stream: TokenStream) -> TokenStream {
         CompilerConfiguration::new(sixtyfps_compilerlib::generator::OutputFormat::Rust);
 
     if std::env::var_os("SIXTYFPS_STYLE").is_none() {
-        compiler_config.style = std::fs::read_to_string(env!("SIXTYFPS_DEFAULT_STYLE_PATH"))
-            .map(|style| style.trim().into())
-            .ok()
+        // This file is written by the sixtyfps-rendering-backend-default's built script.
+        // It is in the target/xxx/build directory
+        let target_path = match std::env::var_os("OUT_DIR") {
+            Some(out_dir) => Some(
+                Path::new(&out_dir)
+                    .parent()
+                    .unwrap()
+                    .parent()
+                    .unwrap()
+                    .join("SIXTYFPS_DEFAULT_STYLE.txt"),
+            ),
+            None => {
+                // OUT_DIR is only defined when the crate having the macro has a build.rs script
+                // as a fallback, try to parse the rustc arguments
+                // https://stackoverflow.com/questions/60264534/getting-the-target-folder-from-inside-a-rust-proc-macro
+                let mut args = std::env::args();
+                let mut out_dir = None;
+                while let Some(arg) = args.next() {
+                    if arg == "--out-dir" {
+                        out_dir = args.next();
+                    }
+                }
+                out_dir.map(|out_dir| {
+                    Path::new(&out_dir).parent().unwrap().join("build/SIXTYFPS_DEFAULT_STYLE.txt")
+                })
+            }
+        };
+        if let Some(target_path) = target_path {
+            compiler_config.style =
+                std::fs::read_to_string(target_path).map(|style| style.trim().into()).ok()
+        }
     }
 
     compiler_config.include_paths = include_paths;
-    let (root_component, mut diag) =
+    let (root_component, diag) =
         spin_on::spin_on(compile_syntax_node(syntax_node, diag, compiler_config));
     //println!("{:#?}", tree);
     if diag.has_error() {
         return diag.report_macro_diagnostic(&tokens);
     }
 
-    let mut result = generator::rust::generate(&root_component, &mut diag);
+    let mut result = generator::rust::generate(&root_component);
 
     // Make sure to recompile if any of the external files changes
     let reload = diag
@@ -367,11 +390,9 @@ pub fn sixtyfps(stream: TokenStream) -> TokenStream {
         .filter(|path| path.is_absolute() && !path.ends_with("Cargo.toml"))
         .filter_map(|p| p.to_str())
         .map(|p| quote! {const _ : &'static [u8] = ::core::include_bytes!(#p);});
-    if let Some(x) = result.as_mut() {
-        x.extend(reload);
-        x.extend(quote! {const _ : Option<&'static str> = ::core::option_env!("SIXTYFPS_STYLE");});
-    }
 
-    let diags = diag.report_macro_diagnostic(&tokens);
-    result.map_or(diags, |r| r.into())
+    result.extend(reload);
+    result.extend(quote! {const _ : Option<&'static str> = ::core::option_env!("SIXTYFPS_STYLE");});
+
+    result.into()
 }
